@@ -34,17 +34,18 @@ from errors import *
 from ast import Datum, DB, expr
 
 class Cursor(object):
-    def __init__(self, conn, query, term, chunk, complete):
-        self.chunks = [chunk]
+    def __init__(self, conn, opts, query, term, chunk, complete):
         self.conn = conn
+        self.opts = opts
         self.query = query
         self.term = term
+        self.chunks = [chunk]
         self.end_flag = complete
 
     def _read_more(self):
         if self.end_flag:
             return False
-        other = self.conn._continue(self.query, self.term)
+        other = self.conn._continue(self.query, self.term, self.opts)
         self.chunks.extend(other.chunks)
         self.end_flag = other.end_flag
         return True
@@ -66,11 +67,17 @@ class Connection(object):
     def __init__(self, host, port, db, auth_key, timeout):
         self.socket = None
         self.host = host
-        self.port = port
         self.next_token = 1
         self.db = db
         self.auth_key = auth_key
         self.timeout = timeout
+
+        # Try to convert the port to an integer
+        try:
+          self.port = int(port)
+        except ValueError as err:
+          raise RqlDriverError("Could not convert port %s to an integer." % port)
+
         self.reconnect()
 
     def __enter__(self):
@@ -147,19 +154,15 @@ class Connection(object):
             pair.key = k
             expr(v).build(pair.val)
 
-        noreply = False
-        if 'noreply' in global_opt_args:
-            noreply = global_opt_args['noreply']
-
         # Compile query to protobuf
         term.build(query.query)
-        return self._send_query(query, term, noreply)
+        return self._send_query(query, term, global_opt_args)
 
-    def _continue(self, orig_query, orig_term):
+    def _continue(self, orig_query, orig_term, opts):
         query = p.Query()
         query.type = p.Query.CONTINUE
         query.token = orig_query.token
-        return self._send_query(query, orig_term)
+        return self._send_query(query, orig_term, opts)
 
     def _end(self, orig_query, orig_term):
         query = p.Query()
@@ -167,7 +170,7 @@ class Connection(object):
         query.token = orig_query.token
         return self._send_query(query, orig_term)
 
-    def _send_query(self, query, term, noreply=False):
+    def _send_query(self, query, term, opts={}):
 
         # Error if this connection has closed
         if not self.socket:
@@ -178,7 +181,7 @@ class Connection(object):
         query_header = struct.pack("<L", len(query_protobuf))
         self.socket.sendall(query_header + query_protobuf)
 
-        if noreply:
+        if opts.has_key('noreply') and opts['noreply']:
             return None
 
         # Get response
@@ -214,6 +217,10 @@ class Connection(object):
             # This response is corrupted or not intended for us.
             raise RqlDriverError("Unexpected response received.")
 
+        time_format = 'native'
+        if opts.has_key('time_format'):
+            time_format = opts['time_format']
+
         # Error responses
         if response.type == p.Response.RUNTIME_ERROR:
             message = Datum.deconstruct(response.response[0])
@@ -233,14 +240,14 @@ class Connection(object):
 
         # Sequence responses
         elif response.type == p.Response.SUCCESS_PARTIAL or response.type == p.Response.SUCCESS_SEQUENCE:
-            chunk = [Datum.deconstruct(datum) for datum in response.response]
-            return Cursor(self, query, term, chunk, response.type == p.Response.SUCCESS_SEQUENCE)
+            chunk = [Datum.deconstruct(datum, time_format) for datum in response.response]
+            return Cursor(self, opts, query, term, chunk, response.type == p.Response.SUCCESS_SEQUENCE)
 
         # Atom response
         elif response.type == p.Response.SUCCESS_ATOM:
             if len(response.response) < 1:
                 return None
-            return Datum.deconstruct(response.response[0])
+            return Datum.deconstruct(response.response[0], time_format)
 
         # Default for unknown response types
         else:
